==> zio-aws-fms_2.13-5.17.271.1-sources.jar: zio/aws/fms/model/GetViolationDetailsResponse.scala <==
package zio.aws.fms.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetViolationDetailsResponse(
    violationDetail: Optional[zio.aws.fms.model.ViolationDetail] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fms.model.GetViolationDetailsResponse = {
    import GetViolationDetailsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fms.model.GetViolationDetailsResponse
      .builder()
      .optionallyWith(violationDetail.map(value => value.buildAwsValue()))(
        _.violationDetail
      )
      .build()
  }
  def asReadOnly: zio.aws.fms.model.GetViolationDetailsResponse.ReadOnly =
    zio.aws.fms.model.GetViolationDetailsResponse.wrap(buildAwsValue())
}
object GetViolationDetailsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fms.model.GetViolationDetailsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.fms.model.GetViolationDetailsResponse =
      zio.aws.fms.model.GetViolationDetailsResponse(
        violationDetail.map(value => value.asEditable)
      )
    def violationDetail: Optional[zio.aws.fms.model.ViolationDetail.ReadOnly]
    def getViolationDetail
        : ZIO[Any, AwsError, zio.aws.fms.model.ViolationDetail.ReadOnly] =
      AwsError.unwrapOptionField("violationDetail", violationDetail)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fms.model.GetViolationDetailsResponse
  ) extends zio.aws.fms.model.GetViolationDetailsResponse.ReadOnly {
    override val violationDetail
        : Optional[zio.aws.fms.model.ViolationDetail.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.violationDetail())
        .map(value => zio.aws.fms.model.ViolationDetail.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.fms.model.GetViolationDetailsResponse
  ): zio.aws.fms.model.GetViolationDetailsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-fms_3-5.17.126.2-sources.jar: zio/aws/fms/model/GetViolationDetailsResponse.scala <==
package zio.aws.fms.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetViolationDetailsResponse(
    violationDetail: Option[zio.aws.fms.model.ViolationDetail] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fms.model.GetViolationDetailsResponse = {
    import GetViolationDetailsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fms.model.GetViolationDetailsResponse
      .builder()
      .optionallyWith(violationDetail.map(value => value.buildAwsValue()))(
        _.violationDetail
      )
      .build()
  }
  def asReadOnly: zio.aws.fms.model.GetViolationDetailsResponse.ReadOnly =
    zio.aws.fms.model.GetViolationDetailsResponse.wrap(buildAwsValue())
}
object GetViolationDetailsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fms.model.GetViolationDetailsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.fms.model.GetViolationDetailsResponse =
      zio.aws.fms.model.GetViolationDetailsResponse(
        violationDetail.map(value => value.asEditable)
      )
    def violationDetail: Option[zio.aws.fms.model.ViolationDetail.ReadOnly]
    def getViolationDetail
        : ZIO[Any, AwsError, zio.aws.fms.model.ViolationDetail.ReadOnly] =
      AwsError.unwrapOptionField("violationDetail", violationDetail)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fms.model.GetViolationDetailsResponse
  ) extends zio.aws.fms.model.GetViolationDetailsResponse.ReadOnly {
    override val violationDetail
        : Option[zio.aws.fms.model.ViolationDetail.ReadOnly] = scala
      .Option(impl.violationDetail())
      .map(value => zio.aws.fms.model.ViolationDetail.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.fms.model.GetViolationDetailsResponse
  ): zio.aws.fms.model.GetViolationDetailsResponse.ReadOnly = new Wrapper(impl)
}
